.. _index:

ggf documentation
=================

ggf is a Python library for computing global geometric factors and
corresponding stresses acting on dielectric objects in the
optical stretcher. This is the documentation of ggf
version |release|.

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   sec_installation
   sec_introduction
   sec_concept_theory
   sec_examples
   sec_code_reference
   sec_changelog
   sec_z_bib


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
